"""UberSolar get device info test."""
import logging
import asyncio

from . import UberSmart, GetUberSolarDevices

logger = logging.getLogger(__name__)


async def main():
    """Main program."""

    log_level = logging.INFO
    logging.basicConfig(
        level=log_level,
        format="%(asctime)-15s %(name)-8s %(levelname)s: %(message)s",
    )

    logger.info("starting scan...")
    device = GetUberSolarDevices()
    await device.discover()

    if device._adv_data:
        logger.info("connecting to device...")
        for item in device._adv_data:
            uber_smart = UberSmart(device._adv_data[item].device)
            await uber_smart.get_info()
            print(uber_smart.status_data)

    logger.info("Could not find any UberSolar devices in range")


if __name__ == "__main__":
    asyncio.run(main())



"""Library to handle connection with UberSmart."""
from __future__ import annotations

import logging
from typing import Any

from .device import UberSolarBaseDevice

_LOGGER = logging.getLogger(__name__)


class UberSmart(UberSolarBaseDevice):
    """Representation of a UberSmart Device."""

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        """UberSolar UberSmart constructor."""

        super().__init__(*args, **kwargs)

    async def get_info(self) -> dict[str, Any] | None:
        """Get device statuses."""

        await self._send_command()
        if not self.status_data[self._device.address]:
            _LOGGER.error("%s: Unsuccessful, no result from device", self.name)
            return None

        return self.status_data[self._device.address]

    async def set_pump(self) -> dict[str, Any] | None:
        """Set pump switch."""

        await self._send_command(key="00010002")
        if not self.status_data[self._device.address]:
            _LOGGER.error("%s: Unsuccessful, no result from device", self.name)
            return None

        return
